@@ -23,6 +23,7 @@ looper_data_t* looperdata_new(buffer_info_t* buf, long samplerate,int id){
 	looper_data_t *data = (looper_data_t*) malloc (sizeof(looper_data_t));
 
 	data->buf = buf;
+	data->looper_id = -1;
 	data->clickmode_buf = NULL;
 	data->reverb = buffer_new(id,samplerate);
 	buffer_set_channels(data->reverb,2);
@@ -427,6 +428,8 @@ void looperdata_set_panswing(looper_data_t* data, float panswing){
 void looperdata_set_vol(looper_data_t* data, float vol){
 	if (vol < .0){vol = 0.;}
 	data->vol = vol;
+
+/*	if (data->buf) printf ("data:%s, vol:%f\n",data->buf->shortname, vol);*/
 	/* recalculate Lfact + Rfact */
 	looperdata_calc_pan(data);
 }
@@ -626,6 +629,7 @@ static void looperdata_reset_grain (looper_data_t* data, int grain){
 		}else{
 			*(data->grainspeeds  + grain) = 1;
 			*(data->grainsactive + grain) = 0;	
+			*(data->grainpitchvolumes + grain) = 0.0;
 		}
 	} else {
 		/* GRAINPITCH_AUTO and GRAINPITCH_RANGE are based on the predefined pitch range */
@@ -659,13 +663,19 @@ static void looperdata_reset_grain (looper_data_t* data, int grain){
 		*(data->grainoffsets + grain) -= data->loopend - data->loopstart;
 	}
 
-	/*calculate mix factor for volume: */
-	for (i = 0; i < data->ngrains;i++){
-		if (*(data->grainsactive + grain)) a++;
+	if (data->grainpitchmode == GRAINPITCH_CHORD){
+		/* avoid stuttering volumechanges */
+		data->grainmixfactor =  1.0f / sqrt((float)data->ngrains);
+	
+	} else {
+		/*calculate mix factor for volume: */
+		for (i = 0; i < data->ngrains;i++){
+			if (*(data->grainsactive + grain)) a++;
+		}
+		if (a < 1) a = 1;
+		data->grainmixfactor =  1.0f / sqrt((float)a);
+	/*	printf ("mixfactor:%lf\n", data->grainmixfactor);	*/
 	}
-	if (a < 1) a = 1;
-	data->grainmixfactor =  1.0f / sqrt((float)a);
-/*	printf ("mixfactor:%lf\n", data->grainmixfactor);	*/
 }
 
 void looperdata_set_grainpitchmode ( looper_data_t* data, int mode){
@@ -704,13 +714,14 @@ void looperdata_set_grainpitchtablevalue ( looper_data_t* data, double value, do
 	int i = 0;
 	int found = 0;
 
-/*	printf ("set grainpitch:%lf - %lf\n",value,vol);	*/
+/*	printf ("set grainpitch:%lf - %lf\n",value,vol);*/
 	if (vol == 0.){
+/*		printf ("vol 0\n");*/
 		while (!found && (i < data->ngrains)){
 			if (*(data->grainpitchtable + i) == value){
 				if (data->grainpitchmode == GRAINPITCH_CHORD){
-					*(data->grainpitchtable + i) = 0.; /* mute */
-/*					*(data->grainpitchvolumes + i) = 0.;*/
+					*(data->grainpitchtable + i) = 0.;
+/*					*(data->grainpitchvolumes + i) = 0.; */ /* mute  without fade !!!*/
 				}else{
 				 	*(data->grainpitchtable + i) = 1.; /* fall back to regular volume */
 					*(data->grainpitchvolumes + i) = 0;
@@ -722,7 +733,8 @@ void looperdata_set_grainpitchtablevalue ( looper_data_t* data, double value, do
 	}else{
 		while (!found && (i < data->ngrains)){
 			if (data->grainpitchmode == GRAINPITCH_CHORD){
-				if (*(data->grainpitchtable + i) == 0.){
+				if (*(data->grainsactive + i) == 0){
+/*				if (*(data->grainpitchtable + i) == 0.){*/
 					*(data->grainpitchtable + i) = value;
 					*(data->grainpitchvolumes + i) = vol;
 					found++;
@@ -771,21 +783,29 @@ void looperdata_set_grainpitchbend (looper_data_t* data, double bend){
 }
 
 void looperdata_set_loopstart(looper_data_t* data, long start){
-	if (data && (start > 1)){
+	if (!data) return;
+	if (data->buf){
+		if (start > buffer_get_size(data->buf)) 
+			start = buffer_get_size(data->buf) - 1;
+		if (start < 1) start = 1;
 		data->loopstart = start;
 		if (data->loopstart >= data->loopend)
-			data->loopend  = data->loopstart + 1;
+                        data->loopend  = data->loopstart + 1;
 	}
 	inform_buffer(data);
 }
 
 void looperdata_set_loopend(looper_data_t* data, long end){
-	if (data && (end > 1)){
+	if (!data) return;
+	if (data->buf){
+		if (end > buffer_get_size(data->buf))
+                        end = buffer_get_size(data->buf) - 1;
+		if (end < 2) end = 2;
 		data->loopend = end;
 		if (data->loopstart >= data->loopend)
-			data->loopend  = data->loopstart + 1;
+                        data->loopend  = data->loopstart + 1;
 	}
-	inform_buffer(data);
+	inform_buffer(data);	
 }
 
 void looperdata_set_playmode(looper_data_t* data,int mode){
@@ -808,11 +828,29 @@ long looperdata_get_loopend(looper_data_t* data){
 }
 
 void looperdata_set_recstart(looper_data_t* data, long start){
-	data->recstart = start;
+	if (!data) return;
+        if (data->buf){
+                if (start > buffer_get_size(data->buf))
+                        start = buffer_get_size(data->buf) - 2;
+                if (start < 1) start = 1;
+                data->recstart = start;
+                if (data->recstart >= data->recend)
+                        data->recend = data->loopstart + 1;
+        }
+        inform_buffer(data);
 }
 
 void looperdata_set_recend(looper_data_t* data, long end){
-	data->recend = end;
+	if (!data) return;
+        if (data->buf){
+                if (end > buffer_get_size(data->buf))
+                        end = buffer_get_size(data->buf) - 1;
+                if (end < 2) end = 2;
+                data->recend = end;
+                if (data->recstart >= data->recend)
+                        data->recend  = data->recstart + 1;
+        }
+        inform_buffer(data);
 }
 
 void looperdata_set_playpos(looper_data_t* data, double playpos){
@@ -962,8 +1000,11 @@ int looperdata_get_ngrains (looper_data_t* data){
 void looperdata_set_ngrains (looper_data_t* data, int ngrains){
 	int i;
 /*	int a = 0;*/
+	if (ngrains == data->ngrains) return;
 	if (ngrains < 0) ngrains = 0;
 	if (ngrains > 15) ngrains = 15;
+	
+/*	printf ("ngrains:%d\n",ngrains);*/
 
 	if (ngrains){
 		data->grainindexes = realloc (data->grainindexes, sizeof(float) * ngrains);
@@ -979,6 +1020,7 @@ void looperdata_set_ngrains (looper_data_t* data, int ngrains){
 
 		if (data->buf){
 			for (i = data->ngrains; i < ngrains; i++){
+/*				printf ("initialising grain nr. %d\n",i);*/
 				looperdata_reset_grain(data,i);
 				if (data->grainpitchmode == GRAINPITCH_CHORD){
 					data->grainpitchtable[i] = 0.;
@@ -1163,9 +1205,10 @@ static double grain_inc(looper_data_t* data, int i){
 
 	*(data->grainindexes + i) += 1;
 
-	if (*(data->grainindexes + i) >= *(data->grainsizes + i))
+	if (*(data->grainindexes + i) >= *(data->grainsizes + i)){
+/*		printf ("index:%ld, size:%ld\n",*(data->grainindexes + i), *(data->grainsizes + i));*/
 		looperdata_reset_grain (data,i);
-	else{
+	} else {
 		pos = (float)*(data->grainoffsets + i) + *(data->grainindexes + i) 
 							* *(data->grainspeeds + i);
 		/* check if still inside the loop: */
@@ -1198,13 +1241,12 @@ void looperdata_calc_sample_stereo(looper_data_t* data, float* L, float* R){
 		for (i = 0; i < data->ngrains; i++){
 			pos = grain_inc(data,i);
 			if (*(data->grainsactive + i)){
-				if (*(data->grainindexes + i) < *(data->grainfadelengths + i))
+				if (*(data->grainindexes + i) < *(data->grainfadelengths + i)){
 					vol = (float)*(data->grainindexes + i) / (float)*(data->grainfadelengths + i);
-				else if ( (ipos = (*(data->grainsizes + i) 
-					- *(data->grainindexes + i))) 
-					< *(data->grainfadelengths + i))
+				} else if ( (ipos = (*(data->grainsizes + i) - *(data->grainindexes + i)))
+						< *(data->grainfadelengths + i)){
 					vol = ipos / (float)*(data->grainfadelengths + i);
-				else vol = 1.;
+				} else vol = 1.;
 
 				vol *= data->grainmixfactor * *(data->grainpitchvolumes + i);
 
