@@ -1223,6 +1223,25 @@ void create_settings(buffer_info_t* buf, jack_info_t* jack_info){
         snprintf((char*)&ls->name,20,"D7");
         speciallist_append(settingslist,(void*)ls);
 
+	/* resonator / ringmod-like */
+	ld = looperdata_new(buf, jack_info->samplerate, 1);
+        reset_looperdata(ld,jack_info);
+        looperdata_lock(ld);
+	looperdata_set_ngrains(ld,1);
+        looperdata_set_stereodiversity(ld,0.4);
+        looperdata_set_maxgrainlength (ld, 56);
+        looperdata_set_loopend (ld, 56);
+        looperdata_set_recend (ld, 56);
+        looperdata_set_mingrainlength(ld,56);
+        looperdata_set_stereodiversity(ld,0.);
+        ld->isrecording = 1;
+        looperdata_unlock(ld);
+	set_distortion(ld,0.6);
+        ls = malloc(sizeof(looper_settings_t));
+        ls->looper_data = ld;
+        snprintf((char*)&ls->name,20,"Resonator");
+        speciallist_append(settingslist,(void*)ls);
+
 	/* dominantseptakkord miniloop distorted*/
         ld = looperdata_new(buf, jack_info->samplerate, 1);
 	reset_looperdata(ld,jack_info);
