@@ -14,7 +14,8 @@ typedef struct _configfile_handler {
 	long samplerate;
 } configfile_handler_t;
 
-int save_config (GList *looperlist, speciallist_t *bufferlist, char* spath, char* cpath, char *filename, gint x, gint y, gint width, gint height);
+int save_config (GList *looperlist, speciallist_t *bufferlist, char* spath, char* cpath, char *filename, 
+			gint x, gint y, gint width, gint height, long samplerate);
 char* config_check_filename (char *filename);
 configfile_handler_t* open_config_reader (char *filename, long samplerate);
 void close_config_reader (configfile_handler_t* handler);
