@@ -518,7 +518,7 @@ void gtk_loopview_update_loopstart (GtkLoopview *loopview){
 
 	loopview->gloopstart = 
 		gtk_loopview_sample2graphical(loopview,
-			(gdouble)loopview->looperdata->loopstart);
+			(gdouble)looperdata_get_loopstart(loopview->looperdata));
 
 	gtk_loopview_update_area (loopview,
 		MIN (temp, loopview->gloopstart),
@@ -530,7 +530,7 @@ void gtk_loopview_update_loopend (GtkLoopview *loopview){
 
 	loopview->gloopend =
 		gtk_loopview_sample2graphical(loopview,
-			(gdouble)loopview->looperdata->loopend);
+			(gdouble)looperdata_get_loopend(loopview->looperdata));
 
 	gtk_loopview_update_area (loopview,
 		MIN (temp, loopview->gloopend),
