@@ -20,9 +20,12 @@
 #include "sfpreview.h"
 #include "../../common/speciallist.h"
 #include "../../common/clickmodes.h"
+#include "../../common/alphatrack.h"
+#include "alphatrack_callback.h"
 
 #ifdef HAVE_ALSA
 #include "../../common/midi.h"
+#include "../../common/xsession.h"
 #endif
 
 #ifdef HAVE_OSC
@@ -59,6 +62,7 @@ GtkWidget *window;
 
 /* global data */
 speciallist_t *buffer_list;
+alphatrack_t *alphatrack = NULL;
 
 int emptybuffercounter = 0;
 configfile_handler_t *ch;
@@ -97,6 +101,7 @@ jack_info_t *jack_info;
 
 #ifdef HAVE_ALSA
 midi_info_t *midi_info;
+xsession_info_t *xsession_info;
 #endif
 
 #ifdef HAVE_OSC
@@ -402,7 +407,7 @@ gint main_idlefunc(gpointer data){
 		while ((ti = config_next_looper(ch)) != 0){
 /*			printf ("new looper:%d\n",ti);*/
 			if (looperindexcounter < ti) looperindexcounter = ti;
-			looper = looper_new(window, globalbox, looperdatalist, clickmode_list, ti, 
+			looper = looper_new(window, globalbox, alphatrack, looperdatalist, clickmode_list, ti, 
 					config_get_looper_minimized (ch, ti));
 			if (jack_info->samplerate)
 				looper_set_samplerate(looper,jack_info->samplerate);
@@ -846,7 +851,7 @@ static void create_empty_buffer(gpointer data){
 }
 	
 static void create_looper(gpointer data){	
-	looper_gui_t *loop = looper_new(window, globalbox, looperdatalist, clickmode_list, ++looperindexcounter, 0);
+	looper_gui_t *loop = looper_new(window, globalbox, alphatrack, looperdatalist, clickmode_list, ++looperindexcounter, 0);
 /*	printf ("counter:%d\n",looperindexcounter);*/
 
 	if (jack_info->samplerate)
@@ -1038,7 +1043,7 @@ static void create_mainlayout(){
 
 int main(int argc, char *argv[])
 {
-	int retval;
+	int retval/*, count = 0*/;
 	const char *defaultdir = NULL;
 	struct stat fstat;
 
@@ -1056,6 +1061,11 @@ int main(int argc, char *argv[])
 #ifdef HAVE_ALSA
         /* create midi thread: */
         midi_info = midi_info_new(looperdatalist);
+/*
+  	xsession somehow interferes with note-off events - check before enabling
+	while (!midi_info->seq && (count++ < 10000)) usleep(10);
+	xsession_info = xsession_new(looperdatalist, midi_info->seq);
+*/
 #endif
 
 #ifdef HAVE_OSC
@@ -1073,6 +1083,17 @@ int main(int argc, char *argv[])
 
         looperlist = looper_list_new();
 
+	/*alphatrack: */
+	alphatrack = alphatrack_new();
+        if (alphatrack){
+                alphatrack_set_event_callback(alphatrack,alphatrack_event_callback,looperlist);
+		alphatrack_write_lcd(alphatrack,"kluppe says hi! ",0,0);
+		alphatrack_write_lcd(alphatrack,"                ",0,1);
+		alphatrack_set_faderpos(alphatrack,0);
+		alphatrack_clear_leds(alphatrack);
+	}
+	
+
 	/* create main gui elements */
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW (window), jack_info->name);
