@@ -9,6 +9,7 @@
 #include "gtkloopview.h"
 #include "../../common/speciallist.h"
 #include "../../common/shuttle.h"
+#include "../../common/alphatrack.h"
 
 typedef struct _looper_list {
         GList   *listptr;
@@ -18,14 +19,26 @@ typedef struct _looper_list {
 typedef struct _looper_gui {
 	/* for usb hid interaction */
 	shuttle_data_t  *shuttle;
+	alphatrack_t 	*alphatrack;
+
+	/* alphatrack specific:*/
+	int		encoderdelta_l;
+	int		encoderdelta_m;
+	int		encoderdelta_r;
+	long		touchstrippos;
+	long		touchstripposval;
+	long		touchstripposrange;
 
 	/* for mix <-> gui communication */
 	looper_data_t	*data;
 	int		id;
 	int		gid;
+	int 		dirty;
 	GtkWidget	*parent;
 	GtkWidget	*parentcontainer;
 	int 		vposition;
+	int		remote_controlled;
+	int		bg_set;
 	long		samplerate;
 /*	GList		*bufferlist;*/
 	speciallist_t   *bufferlist;
@@ -40,6 +53,7 @@ typedef struct _looper_gui {
 	gboolean        recendblock;
 	gboolean        reclengthblock;
 	gboolean	speedblock;
+	gboolean	volblock;
 
 	/* update meters every second round */
 	gboolean	vublock;
@@ -117,7 +131,8 @@ typedef struct _looper_gui {
 	
 } looper_gui_t;
 
-looper_gui_t* looper_new(GtkWidget* parent, GtkWidget* parentcontainer, speciallist_t *looperdatalist, 
+looper_gui_t* looper_new(GtkWidget* parent, GtkWidget* parentcontainer, 
+				alphatrack_t *alphatrack, speciallist_t *looperdatalist, 
 				speciallist_t *clickmodes, int id, int minimized);
 int looper_update_bufferlist(looper_gui_t* loop, speciallist_t *bufferlist);
 int looper_update_loopername(gchar* name);
@@ -126,6 +141,8 @@ void looper_update_widgets(looper_gui_t *looper);
 void looper_set_samplerate (looper_gui_t *looper,long samplerate);
 void looper_set_buffer_by_id (looper_gui_t *looper, int id);
 void looper_suspend_gui (looper_gui_t *looper, int suspend);
+void looper_set_remote_controlled (looper_gui_t *looper, int rc);
+int looper_get_remote_controlled (looper_gui_t *looper);
 
 looper_data_t* looper_get_looperdata (looper_gui_t *looper);
 
